@@ -50,7 +50,7 @@ def _get_prefixes_max_len():
 
 
 def _is_numpy_array_byte_order_mismatch(array):
-    """Check if numpy array is having byte order mis-match"""
+    """Check if numpy array is having byte order mismatch"""
     return ((sys.byteorder == 'big' and
              (array.dtype.byteorder == '<' or
               (array.dtype.byteorder == '|' and array.dtype.fields and
@@ -69,7 +69,7 @@ def _ensure_native_byte_order(array):
     Does nothing if array already uses the system byte order.
     """
     if _is_numpy_array_byte_order_mismatch(array):
-        array = array.byteswap().newbyteorder('=')
+        array = array.byteswap().view(array.dtype.newbyteorder('='))
     return array
 
 
